@@ -2,4 +2,5 @@ from .probability.outcome import Outcome
 from .probability.event import *
 from .probability.sample_space import SampleSpace
 from .probability.random_variable import RandomVariable
-from .probability.probability_measure import ProbabilityMeasure, P__
\ No newline at end of file
+from .probability.probability_measure import ProbabilityMeasureOfEvent, P__
+from .datatype import ProbabilityDistribution
\ No newline at end of file
